@@ -12,8 +12,8 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program; if not, please see
+#    <http://www.gnu.org/licenses/>
 """
 Simple class wrappers for the various external commands needed by
 git-buildpackage and friends
@@ -169,12 +169,14 @@ class Command(object):
         Traceback (most recent call last):
         ...
         CommandExecFailed: execution failed: ...
-        >>> c = Command("/bin/true", capture_stdout=True)
+        >>> c = Command("/bin/true", capture_stdout=True,
+        ...             extra_env={'LC_ALL': 'C'})
         >>> c.call(["--version"])
         0
         >>> c.stdout.decode('utf-8').startswith('true')
         True
-        >>> c = Command("/bin/false", capture_stdout=True)
+        >>> c = Command("/bin/false", capture_stdout=True,
+        ...             extra_env={'LC_ALL': 'C'})
         >>> c.call(["--help"])
         1
         >>> c.stdout.decode('utf-8').startswith('Usage:')
@@ -258,7 +260,7 @@ class Dch(Command):
         args = ['-v', version]
         if msg:
             args.append(msg)
-        Command.__init__(self, 'dch', args)
+        Command.__init__(self, 'debchange', args)
         self.run_error = "Dch failed: {err_reason}"
 
 
