@@ -12,8 +12,8 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program; if not, please see
+#    <http://www.gnu.org/licenses/>
 """A Debian Changelog"""
 
 from __future__ import print_function
@@ -261,7 +261,7 @@ class ChangeLog(object):
             args.append('[[[insert-git-dch-commit-message-here]]]')
         else:
             args.append('')
-        dch = Command('dch', args, extra_env=env)
+        dch = Command('debchange', args, extra_env=env)
         dch.call([])
         if msg:
             old_cl = open("debian/changelog", "r")
