@@ -12,8 +12,8 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program; if not, please see
+#    <http://www.gnu.org/licenses/>
 """A Git repository"""
 
 import six
@@ -420,7 +420,10 @@ class GitRepository(object):
         args = GitArgs()
         args.add(commit1)
         args.add(commit2)
-        sha1, stderr, ret = self._git_inout('merge-base', args.args, capture_stderr=True)
+        sha1, stderr, ret = self._git_inout('merge-base',
+                                            args.args,
+                                            extra_env={'LC_ALL': 'C'},
+                                            capture_stderr=True)
         if not ret:
             return self.strip_sha1(sha1).decode('utf-8')
         else:
@@ -577,6 +580,7 @@ class GitRepository(object):
 
         dummy, err, ret = self._git_inout('branch',
                                           args,
+                                          extra_env={'LC_ALL': 'C'},
                                           capture_stderr=True)
         if ret:
             raise GitRepositoryError(
@@ -694,10 +698,11 @@ class GitRepository(object):
         args.add(commitish)
 
         tag, err, ret = self._git_inout('describe', args.args,
+                                        extra_env={'LC_ALL': 'C'},
                                         capture_stderr=True)
         if ret:
-            raise GitRepositoryError("Can't describe %s. Git error: %s" % \
-                                         (commitish, err.strip()))
+            raise GitRepositoryError("Can't describe %s. Git error: %s" %
+                                     (commitish, err.strip()))
         return tag.strip()
 
     def find_tag(self, commit, pattern=None):
@@ -1079,7 +1084,9 @@ class GitRepository(object):
         @return: remote repositories
         @rtype: C{dict} of C{GitRemote}
         """
-        out, err, ret = self._git_inout('remote', [], capture_stderr=True)
+        out, err, ret = self._git_inout('remote', [],
+                                        extra_env={'LC_ALL': 'C'},
+                                        capture_stderr=True)
         if ret:
             raise GitRepositoryError('Failed to get list of remotes: %s' % err)
 
@@ -1087,6 +1094,7 @@ class GitRepository(object):
         remotes = {}
         for remote in out.splitlines():
             out, err, _ret = self._git_inout('remote', ['show', '-n', remote],
+                                             extra_env={'LC_ALL': 'C'},
                                              capture_stderr=True)
             if ret:
                 raise GitRepositoryError('Failed to get information for remote '
