@@ -13,8 +13,8 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program; if not, please see
+#    <http://www.gnu.org/licenses/>
 """Import an RPM source package into a Git repository"""
 
 from six.moves import configparser
@@ -25,7 +25,8 @@ import glob
 import time
 import shutil
 import errno
-import urllib2
+from six.moves.urllib.request import urlopen
+from six.moves import urllib
 
 import gbp.tmpfile as tempfile
 import gbp.command_wrappers as gbpc
@@ -53,20 +54,20 @@ def download_file(target_dir, url):
     """Download a remote file"""
     gbp.log.info("Downloading '%s'..." % url)
     try:
-        urlobj = urllib2.urlopen(url)
+        urlobj = urlopen(url)
         local_fn = os.path.join(target_dir, os.path.basename(url))
         with open(local_fn, "wb") as local_file:
             local_file.write(urlobj.read())
-    except urllib2.HTTPError as err:
+    except urllib.error.HTTPError as err:
         raise GbpError("Download failed: %s" % err)
-    except urllib2.URLError as err:
+    except urllib.error.URLError as err:
         raise GbpError("Download failed: %s" % err.reason)
     return local_fn
 
 def download_source(pkg, dirs):
     """Download package from a remote location"""
     if re.match(r'[a-z]{1,5}://', pkg):
-        mode = 'python urllib2'
+        mode = 'python urllib'
     else:
         mode = 'yumdownloader'
 
