@@ -65,21 +65,21 @@ def test_filter():
     The filter option should always parse as a list
     >>> import os
     >>> from gbp.config import GbpOptionParser
-    >>> parser = GbpOptionParser('bar')
     >>> tmpdir = str(context.new_tmpdir('bar'))
     >>> confname = os.path.join(tmpdir, 'gbp.conf')
-    >>> parser.config_files = [confname]
     >>> f = open(confname, 'w')
-    >>> f.write('[bar]\\nfilter = asdf\\n')
+    >>> ret = f.write('[bar]\\nfilter = asdf\\n')
     >>> f.close()
-    >>> parser.parse_config_files()
+    >>> os.environ['GBP_CONF_FILES'] = confname
+    >>> parser = GbpOptionParser('bar')
     >>> parser.config['filter']
     ['asdf']
     >>> f = open(confname, 'w')
-    >>> f.write("[bar]\\nfilter = ['this', 'is', 'a', 'list']\\n")
+    >>> ret = f.write("[bar]\\nfilter = ['this', 'is', 'a', 'list']\\n")
     >>> f.close()
-    >>> parser.parse_config_files()
+    >>> parser = GbpOptionParser('bar')
     >>> parser.config['filter']
     ['this', 'is', 'a', 'list']
+    >>> del os.environ['GBP_CONF_FILES']
     """
 
