@@ -17,9 +17,9 @@ import gbp.log
 
 gbp.log.setup(color=False, verbose=True)
 
-repo_dir, bare_dir, clone_dir, mirror_clone_dir = map(
+repo_dir, bare_dir, clone_dir, mirror_clone_dir = list(map(
     lambda x, tmpdir=context.new_tmpdir(__name__): tmpdir.join(x),
-    ['repo', 'bare', 'clone', 'mirror_clone'])
+    ['repo', 'bare', 'clone', 'mirror_clone']))
 
 def test_create():
     """
@@ -74,8 +74,8 @@ def test_add_files():
 
     >>> import gbp.git, shutil, os
     >>> repo = gbp.git.GitRepository(repo_dir)
-    >>> shutil.copy(os.path.join(repo.path, ".git/HEAD"), \
-                                 os.path.join(repo.path, "testfile"))
+    >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"),
+    ...                                os.path.join(repo.path, "testfile"))
     >>> repo.is_clean()[0]
     False
     >>> repo.is_clean(ignore_untracked=True)[0]
@@ -113,8 +113,8 @@ def test_clean():
 
     >>> import gbp.git, shutil, os
     >>> repo = gbp.git.GitRepository(repo_dir)
-    >>> shutil.copy(os.path.join(repo.path, ".git/HEAD"), \
-                                 os.path.join(repo.path, "testclean"))
+    >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"),
+    ...                                os.path.join(repo.path, "testclean"))
     >>> repo.clean(dry_run=True)
     >>> repo.is_clean()[0]
     False
@@ -202,7 +202,7 @@ def test_set_upstream_branch():
     >>> import gbp.git
     >>> repo = gbp.git.GitRepository(repo_dir)
     >>> os.makedirs(os.path.join(repo.git_dir, 'refs/remotes/origin'))
-    >>> shutil.copy(os.path.join(repo.git_dir, 'refs/heads/master'), \
+    >>> ret = shutil.copy(os.path.join(repo.git_dir, 'refs/heads/master'), \
                     os.path.join(repo.git_dir, 'refs/remotes/origin/'))
     >>> repo.add_remote_repo('origin', 'git://git.example.com/git/origin')
     >>> repo.set_upstream_branch('master', 'origin/master')
@@ -309,6 +309,23 @@ def test_find_tag():
     GitRepositoryError: Can't describe HEAD. Git error: fatal: No names found, cannot describe anything.
     """
 
+def test_find_branch_tag():
+    """
+    Find the closest tags on a certain branch to a given commit
+
+    Methods tested:
+         - L{gbp.git.GitRepository.find_branch_tag}
+
+    >>> import gbp.git
+    >>> repo = gbp.git.GitRepository(repo_dir)
+    >>> repo.find_branch_tag('HEAD', 'master', 'tag*')
+    'tag2'
+    >>> repo.find_branch_tag('HEAD', 'master', 'v*')   # doctest:+ELLIPSIS
+    Traceback (most recent call last):
+    ...
+    GitRepositoryError: Can't describe .... Git error: fatal: No names found, cannot describe anything.
+    """
+
 def test_move_tag():
     """
     Move a tag
@@ -387,7 +404,7 @@ def test_list_files():
     []
     >>> repo.list_files(['modified', 'deleted', 'cached'])
     ['testfile']
-    >>> shutil.copy(src, dst)
+    >>> ret = shutil.copy(src, dst)
     >>> repo.list_files(['modified'])
     ['testfile']
     >>> repo.add_files(dst)
@@ -401,7 +418,7 @@ def test_list_files():
     >>> repo.force_head('HEAD^', hard=True)
     >>> repo.list_files(['modified'])
     []
-    >>> shutil.copy(src, dst)
+    >>> ret = shutil.copy(src, dst)
     >>> repo.list_files(['modified'])
     ['testfile']
     >>> repo.commit_files(dst, msg="foo")
@@ -468,8 +485,8 @@ def test_get_commit_info():
     True
     >>> info['patchname']
     'foo'
-    >>> info['files']
-    defaultdict(<type 'list'>, {'M': ['testfile']})
+    >>> info['files']                               # doctest:+ELLIPSIS
+    defaultdict(<... 'list'>, {'M': ['testfile']})
     >>> repo.get_subject('HEAD')
     'foo'
     """
@@ -491,6 +508,21 @@ def test_diff():
     True
     >>> len(repo.diff('HEAD~1', 'HEAD', 'filenotexist')) == 0
     True
+    >>> repo.diff('HEAD~1', 'HEAD') == repo.diff('HEAD~1')
+    True
+    """
+
+def test_diff_status():
+    """
+    Methods tested:
+        - L{gbp.git.GitRepository.diff_status}
+
+    >>> import gbp.git
+    >>> repo = gbp.git.GitRepository(repo_dir)
+    >>> repo.diff_status("HEAD", "HEAD")            # doctest:+ELLIPSIS
+    defaultdict(<... 'list'>, {})
+    >>> repo.diff_status("HEAD~1", "HEAD")          # doctest:+ELLIPSIS
+    defaultdict(<... 'list'>, {'M': ['testfile']})
     """
 
 def test_mirror_clone():
@@ -868,6 +900,28 @@ def test_get_merge_base():
     GitRepositoryError: Failed to get common ancestor: fatal: Not a valid object name doesnotexist
     """
 
+def test_status():
+    r"""
+    Methods tested:
+        - L{gbp.git.GitRepository.status}
+
+    >>> import gbp.git, os, shutil
+    >>> repo = gbp.git.GitRepository(repo_dir)
+    >>> fname = os.path.join(repo.path, "test_status")
+    >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"), fname)
+    >>> list(repo.status().items())
+    [('??', ['test_status'])]
+    >>> list(repo.status(['bla*']).items())
+    []
+    >>> list(repo.status(['te*']).items())
+    [('??', ['test_status'])]
+    >>> repo.add_files(repo.path, force=True)
+    >>> repo.commit_all(msg='added %s' % fname)
+    >>> _ = repo._git_inout('mv', [fname, fname + 'new'])
+    >>> list(repo.status().items())
+    [('R ', ['test_status\x00test_statusnew'])]
+    """
+
 def test_cmd_has_feature():
     r"""
     Methods tested:
